@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: List applications handled by cme
 
 package App::Cme::Command::list ;
-$App::Cme::Command::list::VERSION = '1.008';
+$App::Cme::Command::list::VERSION = '1.009';
 use strict;
 use warnings;
 use 5.10.1;
@@ -38,7 +38,7 @@ my %help = (
 sub execute {
     my ($self, $opt, $args) = @_;
 
-    my ( $categories, $appli_info, $appli_map ) = Config::Model::Lister::available_models;
+    my ( $categories, $appli_info, $appli_map ) = Config::Model::Lister::available_models($opt->dev());
     foreach my $cat ( qw/system user application/ ) {
         my $names = $categories->{$cat} || [];
         next unless @$names;
@@ -60,7 +60,7 @@ App::Cme::Command::list - List applications handled by cme
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 SYNOPSIS
 
@@ -81,7 +81,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
