@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.008';
+$App::Cme::Common::VERSION = '1.009';
 use strict;
 use warnings;
 use 5.10.1;
@@ -94,12 +94,6 @@ sub process_args {
         shift @$args;
     }
 
-    # else cannot distinguish between bogus config_file and modification_instructions
-    my $warn_msg;
-    if ($config_file and not -e $config_file) {
-        warn "Warning: file '$config_file' does not exists.\n";
-    }
-
     $opt->{_application} = $application ;
     $opt->{_config_file} = $config_file;
     $opt->{_root_model}  = $root_model;
@@ -224,7 +218,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 SYNOPSIS
 
@@ -240,7 +234,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
